// This file is generated by kconfig_compiler_kf6 from annotationconfig.kcfg.
// All changes you do to this file will be lost.

#include "annotationconfig.h"

#include <qglobal.h>
#include <QFile>
#include <QQmlEngine>

class AnnotationConfigHelper
{
  public:
    AnnotationConfigHelper() : q(nullptr) {}
    ~AnnotationConfigHelper() { delete q; q = nullptr; }
    AnnotationConfigHelper(const AnnotationConfigHelper&) = delete;
    AnnotationConfigHelper& operator=(const AnnotationConfigHelper&) = delete;
    AnnotationConfig *q;
};
Q_GLOBAL_STATIC(AnnotationConfigHelper, s_globalAnnotationConfig)
AnnotationConfig *AnnotationConfig::self()
{
  if (!s_globalAnnotationConfig()->q) {
    new AnnotationConfig;
    s_globalAnnotationConfig()->q->read();
  }

  return s_globalAnnotationConfig()->q;
}

AnnotationConfig *AnnotationConfig::create(QQmlEngine *, QJSEngine *)
{
  QQmlEngine::setObjectOwnership(self(), QQmlEngine::CppOwnership);
  return self();
}

AnnotationConfig::AnnotationConfig( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalAnnotationConfig()->q);
  s_globalAnnotationConfig()->q = this;
  KConfigCompilerSignallingItem::NotifyFunction notifyFunction = static_cast<KConfigCompilerSignallingItem::NotifyFunction>(&AnnotationConfig::itemChanged);

  setCurrentGroup( QStringLiteral( "Annotations" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesannotationToolType;
  KConfigCompilerSignallingItem  *itemAnnotationToolType;
  KConfigSkeleton::ItemEnum  *innerItemAnnotationToolType;
  innerItemAnnotationToolType = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "annotationToolType" ), mAnnotationToolType, valuesannotationToolType, AnnotationTool::Tool::NoTool );
  itemAnnotationToolType = new KConfigCompilerSignallingItem(innerItemAnnotationToolType, this, notifyFunction, signalAnnotationToolTypeChanged);
  addItem( itemAnnotationToolType, QStringLiteral( "annotationToolType" ) );
  KConfigCompilerSignallingItem  *itemFreehandStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemFreehandStrokeWidth;
  innerItemFreehandStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "freehandStrokeWidth" ), mFreehandStrokeWidth, 4 );
  itemFreehandStrokeWidth = new KConfigCompilerSignallingItem(innerItemFreehandStrokeWidth, this, notifyFunction, signalFreehandStrokeWidthChanged);
  innerItemFreehandStrokeWidth->setMinValue(1);
  addItem( itemFreehandStrokeWidth, QStringLiteral( "freehandStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemHighlighterStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemHighlighterStrokeWidth;
  innerItemHighlighterStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "highlighterStrokeWidth" ), mHighlighterStrokeWidth, 20 );
  itemHighlighterStrokeWidth = new KConfigCompilerSignallingItem(innerItemHighlighterStrokeWidth, this, notifyFunction, signalHighlighterStrokeWidthChanged);
  innerItemHighlighterStrokeWidth->setMinValue(1);
  addItem( itemHighlighterStrokeWidth, QStringLiteral( "highlighterStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemLineStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemLineStrokeWidth;
  innerItemLineStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "lineStrokeWidth" ), mLineStrokeWidth, 4 );
  itemLineStrokeWidth = new KConfigCompilerSignallingItem(innerItemLineStrokeWidth, this, notifyFunction, signalLineStrokeWidthChanged);
  innerItemLineStrokeWidth->setMinValue(1);
  addItem( itemLineStrokeWidth, QStringLiteral( "lineStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemArrowStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemArrowStrokeWidth;
  innerItemArrowStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "arrowStrokeWidth" ), mArrowStrokeWidth, 4 );
  itemArrowStrokeWidth = new KConfigCompilerSignallingItem(innerItemArrowStrokeWidth, this, notifyFunction, signalArrowStrokeWidthChanged);
  innerItemArrowStrokeWidth->setMinValue(1);
  addItem( itemArrowStrokeWidth, QStringLiteral( "arrowStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemRectangleStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemRectangleStrokeWidth;
  innerItemRectangleStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "rectangleStrokeWidth" ), mRectangleStrokeWidth, 2 );
  itemRectangleStrokeWidth = new KConfigCompilerSignallingItem(innerItemRectangleStrokeWidth, this, notifyFunction, signalRectangleStrokeWidthChanged);
  innerItemRectangleStrokeWidth->setMinValue(0);
  addItem( itemRectangleStrokeWidth, QStringLiteral( "rectangleStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemEllipseStrokeWidth;
  KConfigSkeleton::ItemUInt  *innerItemEllipseStrokeWidth;
  innerItemEllipseStrokeWidth = new KConfigSkeleton::ItemUInt( currentGroup(), QStringLiteral( "ellipseStrokeWidth" ), mEllipseStrokeWidth, 2 );
  itemEllipseStrokeWidth = new KConfigCompilerSignallingItem(innerItemEllipseStrokeWidth, this, notifyFunction, signalEllipseStrokeWidthChanged);
  innerItemEllipseStrokeWidth->setMinValue(0);
  addItem( itemEllipseStrokeWidth, QStringLiteral( "ellipseStrokeWidth" ) );
  KConfigCompilerSignallingItem  *itemFreehandStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemFreehandStrokeColor;
  innerItemFreehandStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "freehandStrokeColor" ), mFreehandStrokeColor, QColor( 255,0,0,255 ) );
  itemFreehandStrokeColor = new KConfigCompilerSignallingItem(innerItemFreehandStrokeColor, this, notifyFunction, signalFreehandStrokeColorChanged);
  addItem( itemFreehandStrokeColor, QStringLiteral( "freehandStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemHighlighterStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemHighlighterStrokeColor;
  innerItemHighlighterStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "highlighterStrokeColor" ), mHighlighterStrokeColor, QColor( 255,255,0,255 ) );
  itemHighlighterStrokeColor = new KConfigCompilerSignallingItem(innerItemHighlighterStrokeColor, this, notifyFunction, signalHighlighterStrokeColorChanged);
  addItem( itemHighlighterStrokeColor, QStringLiteral( "highlighterStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemLineStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemLineStrokeColor;
  innerItemLineStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "lineStrokeColor" ), mLineStrokeColor, QColor( 255,0,0,255 ) );
  itemLineStrokeColor = new KConfigCompilerSignallingItem(innerItemLineStrokeColor, this, notifyFunction, signalLineStrokeColorChanged);
  addItem( itemLineStrokeColor, QStringLiteral( "lineStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemArrowStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemArrowStrokeColor;
  innerItemArrowStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "arrowStrokeColor" ), mArrowStrokeColor, QColor( 255,0,0,255 ) );
  itemArrowStrokeColor = new KConfigCompilerSignallingItem(innerItemArrowStrokeColor, this, notifyFunction, signalArrowStrokeColorChanged);
  addItem( itemArrowStrokeColor, QStringLiteral( "arrowStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemRectangleStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemRectangleStrokeColor;
  innerItemRectangleStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "rectangleStrokeColor" ), mRectangleStrokeColor, QColor( 0,0,0,255 ) );
  itemRectangleStrokeColor = new KConfigCompilerSignallingItem(innerItemRectangleStrokeColor, this, notifyFunction, signalRectangleStrokeColorChanged);
  addItem( itemRectangleStrokeColor, QStringLiteral( "rectangleStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemEllipseStrokeColor;
  KConfigSkeleton::ItemColor  *innerItemEllipseStrokeColor;
  innerItemEllipseStrokeColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ellipseStrokeColor" ), mEllipseStrokeColor, QColor( 0,0,0,255 ) );
  itemEllipseStrokeColor = new KConfigCompilerSignallingItem(innerItemEllipseStrokeColor, this, notifyFunction, signalEllipseStrokeColorChanged);
  addItem( itemEllipseStrokeColor, QStringLiteral( "ellipseStrokeColor" ) );
  KConfigCompilerSignallingItem  *itemRectangleFillColor;
  KConfigSkeleton::ItemColor  *innerItemRectangleFillColor;
  innerItemRectangleFillColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "rectangleFillColor" ), mRectangleFillColor, QColor( 255,0,0,255 ) );
  itemRectangleFillColor = new KConfigCompilerSignallingItem(innerItemRectangleFillColor, this, notifyFunction, signalRectangleFillColorChanged);
  addItem( itemRectangleFillColor, QStringLiteral( "rectangleFillColor" ) );
  KConfigCompilerSignallingItem  *itemEllipseFillColor;
  KConfigSkeleton::ItemColor  *innerItemEllipseFillColor;
  innerItemEllipseFillColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "ellipseFillColor" ), mEllipseFillColor, QColor( 255,0,0,255 ) );
  itemEllipseFillColor = new KConfigCompilerSignallingItem(innerItemEllipseFillColor, this, notifyFunction, signalEllipseFillColorChanged);
  addItem( itemEllipseFillColor, QStringLiteral( "ellipseFillColor" ) );
  KConfigCompilerSignallingItem  *itemNumberFillColor;
  KConfigSkeleton::ItemColor  *innerItemNumberFillColor;
  innerItemNumberFillColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "numberFillColor" ), mNumberFillColor, QColor( 255,0,0,255 ) );
  itemNumberFillColor = new KConfigCompilerSignallingItem(innerItemNumberFillColor, this, notifyFunction, signalNumberFillColorChanged);
  addItem( itemNumberFillColor, QStringLiteral( "numberFillColor" ) );
  KConfigCompilerSignallingItem  *itemBlurStrength;
  KConfigSkeleton::ItemDouble  *innerItemBlurStrength;
  innerItemBlurStrength = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "blurStrength" ), mBlurStrength, 0.25 );
  itemBlurStrength = new KConfigCompilerSignallingItem(innerItemBlurStrength, this, notifyFunction, signalBlurStrengthChanged);
  innerItemBlurStrength->setMinValue(0);
  innerItemBlurStrength->setMaxValue(1);
  addItem( itemBlurStrength, QStringLiteral( "blurStrength" ) );
  KConfigCompilerSignallingItem  *itemPixelateStrength;
  KConfigSkeleton::ItemDouble  *innerItemPixelateStrength;
  innerItemPixelateStrength = new KConfigSkeleton::ItemDouble( currentGroup(), QStringLiteral( "pixelateStrength" ), mPixelateStrength, 0.25 );
  itemPixelateStrength = new KConfigCompilerSignallingItem(innerItemPixelateStrength, this, notifyFunction, signalPixelateStrengthChanged);
  innerItemPixelateStrength->setMinValue(0);
  innerItemPixelateStrength->setMaxValue(1);
  addItem( itemPixelateStrength, QStringLiteral( "pixelateStrength" ) );
  KConfigCompilerSignallingItem  *itemTextFont;
  KConfigSkeleton::ItemFont  *innerItemTextFont;
  innerItemTextFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "textFont" ), mTextFont );
  itemTextFont = new KConfigCompilerSignallingItem(innerItemTextFont, this, notifyFunction, signalTextFontChanged);
  addItem( itemTextFont, QStringLiteral( "textFont" ) );
  KConfigCompilerSignallingItem  *itemNumberFont;
  KConfigSkeleton::ItemFont  *innerItemNumberFont;
  innerItemNumberFont = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "numberFont" ), mNumberFont );
  itemNumberFont = new KConfigCompilerSignallingItem(innerItemNumberFont, this, notifyFunction, signalNumberFontChanged);
  addItem( itemNumberFont, QStringLiteral( "numberFont" ) );
  KConfigCompilerSignallingItem  *itemTextFontColor;
  KConfigSkeleton::ItemColor  *innerItemTextFontColor;
  innerItemTextFontColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "textFontColor" ), mTextFontColor, QColor( 0,0,0,255 ) );
  itemTextFontColor = new KConfigCompilerSignallingItem(innerItemTextFontColor, this, notifyFunction, signalTextFontColorChanged);
  addItem( itemTextFontColor, QStringLiteral( "textFontColor" ) );
  KConfigCompilerSignallingItem  *itemNumberFontColor;
  KConfigSkeleton::ItemColor  *innerItemNumberFontColor;
  innerItemNumberFontColor = new KConfigSkeleton::ItemColor( currentGroup(), QStringLiteral( "numberFontColor" ), mNumberFontColor, QColor( 0,0,0,255 ) );
  itemNumberFontColor = new KConfigCompilerSignallingItem(innerItemNumberFontColor, this, notifyFunction, signalNumberFontColorChanged);
  addItem( itemNumberFontColor, QStringLiteral( "numberFontColor" ) );
  KConfigCompilerSignallingItem  *itemFreehandShadow;
  KConfigSkeleton::ItemBool  *innerItemFreehandShadow;
  innerItemFreehandShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "freehandShadow" ), mFreehandShadow, true );
  itemFreehandShadow = new KConfigCompilerSignallingItem(innerItemFreehandShadow, this, notifyFunction, signalFreehandShadowChanged);
  addItem( itemFreehandShadow, QStringLiteral( "freehandShadow" ) );
  KConfigCompilerSignallingItem  *itemLineShadow;
  KConfigSkeleton::ItemBool  *innerItemLineShadow;
  innerItemLineShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "lineShadow" ), mLineShadow, true );
  itemLineShadow = new KConfigCompilerSignallingItem(innerItemLineShadow, this, notifyFunction, signalLineShadowChanged);
  addItem( itemLineShadow, QStringLiteral( "lineShadow" ) );
  KConfigCompilerSignallingItem  *itemArrowShadow;
  KConfigSkeleton::ItemBool  *innerItemArrowShadow;
  innerItemArrowShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "arrowShadow" ), mArrowShadow, true );
  itemArrowShadow = new KConfigCompilerSignallingItem(innerItemArrowShadow, this, notifyFunction, signalArrowShadowChanged);
  addItem( itemArrowShadow, QStringLiteral( "arrowShadow" ) );
  KConfigCompilerSignallingItem  *itemRectangleShadow;
  KConfigSkeleton::ItemBool  *innerItemRectangleShadow;
  innerItemRectangleShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "rectangleShadow" ), mRectangleShadow, true );
  itemRectangleShadow = new KConfigCompilerSignallingItem(innerItemRectangleShadow, this, notifyFunction, signalRectangleShadowChanged);
  addItem( itemRectangleShadow, QStringLiteral( "rectangleShadow" ) );
  KConfigCompilerSignallingItem  *itemEllipseShadow;
  KConfigSkeleton::ItemBool  *innerItemEllipseShadow;
  innerItemEllipseShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ellipseShadow" ), mEllipseShadow, true );
  itemEllipseShadow = new KConfigCompilerSignallingItem(innerItemEllipseShadow, this, notifyFunction, signalEllipseShadowChanged);
  addItem( itemEllipseShadow, QStringLiteral( "ellipseShadow" ) );
  KConfigCompilerSignallingItem  *itemTextShadow;
  KConfigSkeleton::ItemBool  *innerItemTextShadow;
  innerItemTextShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "textShadow" ), mTextShadow, true );
  itemTextShadow = new KConfigCompilerSignallingItem(innerItemTextShadow, this, notifyFunction, signalTextShadowChanged);
  addItem( itemTextShadow, QStringLiteral( "textShadow" ) );
  KConfigCompilerSignallingItem  *itemNumberShadow;
  KConfigSkeleton::ItemBool  *innerItemNumberShadow;
  innerItemNumberShadow = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "numberShadow" ), mNumberShadow, true );
  itemNumberShadow = new KConfigCompilerSignallingItem(innerItemNumberShadow, this, notifyFunction, signalNumberShadowChanged);
  addItem( itemNumberShadow, QStringLiteral( "numberShadow" ) );
}

int AnnotationConfig::defaultAnnotationToolTypeValue_helper()
{

  return AnnotationTool::Tool::NoTool;
}

uint AnnotationConfig::defaultFreehandStrokeWidthValue_helper()
{

  return 4;
}

uint AnnotationConfig::defaultHighlighterStrokeWidthValue_helper()
{

  return 20;
}

uint AnnotationConfig::defaultLineStrokeWidthValue_helper()
{

  return 4;
}

uint AnnotationConfig::defaultArrowStrokeWidthValue_helper()
{

  return 4;
}

uint AnnotationConfig::defaultRectangleStrokeWidthValue_helper()
{

  return 2;
}

uint AnnotationConfig::defaultEllipseStrokeWidthValue_helper()
{

  return 2;
}

QColor AnnotationConfig::defaultFreehandStrokeColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

QColor AnnotationConfig::defaultHighlighterStrokeColorValue_helper()
{

  return QColor( 255,255,0,255 );
}

QColor AnnotationConfig::defaultLineStrokeColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

QColor AnnotationConfig::defaultArrowStrokeColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

QColor AnnotationConfig::defaultRectangleStrokeColorValue_helper()
{

  return QColor( 0,0,0,255 );
}

QColor AnnotationConfig::defaultEllipseStrokeColorValue_helper()
{

  return QColor( 0,0,0,255 );
}

QColor AnnotationConfig::defaultRectangleFillColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

QColor AnnotationConfig::defaultEllipseFillColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

QColor AnnotationConfig::defaultNumberFillColorValue_helper()
{

  return QColor( 255,0,0,255 );
}

double AnnotationConfig::defaultBlurStrengthValue_helper()
{

  return 0.25;
}

double AnnotationConfig::defaultPixelateStrengthValue_helper()
{

  return 0.25;
}

QColor AnnotationConfig::defaultTextFontColorValue_helper()
{

  return QColor( 0,0,0,255 );
}

QColor AnnotationConfig::defaultNumberFontColorValue_helper()
{

  return QColor( 0,0,0,255 );
}

bool AnnotationConfig::defaultFreehandShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultLineShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultArrowShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultRectangleShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultEllipseShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultTextShadowValue_helper()
{

  return true;
}

bool AnnotationConfig::defaultNumberShadowValue_helper()
{

  return true;
}

AnnotationConfig::~AnnotationConfig()
{
  if (s_globalAnnotationConfig.exists() && !s_globalAnnotationConfig.isDestroyed()) {
    s_globalAnnotationConfig()->q = nullptr;
  }
}


void AnnotationConfig::itemChanged(quint64 signalFlag) {

  switch (signalFlag) {
  case signalAnnotationToolTypeChanged:
    Q_EMIT annotationToolTypeChanged();
    break;
  case signalFreehandStrokeWidthChanged:
    Q_EMIT freehandStrokeWidthChanged();
    break;
  case signalHighlighterStrokeWidthChanged:
    Q_EMIT highlighterStrokeWidthChanged();
    break;
  case signalLineStrokeWidthChanged:
    Q_EMIT lineStrokeWidthChanged();
    break;
  case signalArrowStrokeWidthChanged:
    Q_EMIT arrowStrokeWidthChanged();
    break;
  case signalRectangleStrokeWidthChanged:
    Q_EMIT rectangleStrokeWidthChanged();
    break;
  case signalEllipseStrokeWidthChanged:
    Q_EMIT ellipseStrokeWidthChanged();
    break;
  case signalFreehandStrokeColorChanged:
    Q_EMIT freehandStrokeColorChanged();
    break;
  case signalHighlighterStrokeColorChanged:
    Q_EMIT highlighterStrokeColorChanged();
    break;
  case signalLineStrokeColorChanged:
    Q_EMIT lineStrokeColorChanged();
    break;
  case signalArrowStrokeColorChanged:
    Q_EMIT arrowStrokeColorChanged();
    break;
  case signalRectangleStrokeColorChanged:
    Q_EMIT rectangleStrokeColorChanged();
    break;
  case signalEllipseStrokeColorChanged:
    Q_EMIT ellipseStrokeColorChanged();
    break;
  case signalRectangleFillColorChanged:
    Q_EMIT rectangleFillColorChanged();
    break;
  case signalEllipseFillColorChanged:
    Q_EMIT ellipseFillColorChanged();
    break;
  case signalNumberFillColorChanged:
    Q_EMIT numberFillColorChanged();
    break;
  case signalBlurStrengthChanged:
    Q_EMIT blurStrengthChanged();
    break;
  case signalPixelateStrengthChanged:
    Q_EMIT pixelateStrengthChanged();
    break;
  case signalTextFontChanged:
    Q_EMIT textFontChanged();
    break;
  case signalNumberFontChanged:
    Q_EMIT numberFontChanged();
    break;
  case signalTextFontColorChanged:
    Q_EMIT textFontColorChanged();
    break;
  case signalNumberFontColorChanged:
    Q_EMIT numberFontColorChanged();
    break;
  case signalFreehandShadowChanged:
    Q_EMIT freehandShadowChanged();
    break;
  case signalLineShadowChanged:
    Q_EMIT lineShadowChanged();
    break;
  case signalArrowShadowChanged:
    Q_EMIT arrowShadowChanged();
    break;
  case signalRectangleShadowChanged:
    Q_EMIT rectangleShadowChanged();
    break;
  case signalEllipseShadowChanged:
    Q_EMIT ellipseShadowChanged();
    break;
  case signalTextShadowChanged:
    Q_EMIT textShadowChanged();
    break;
  case signalNumberShadowChanged:
    Q_EMIT numberShadowChanged();
    break;
  }
}
